{ pkgs, inputs, config, ... }:
{
  imports = [
    (import ../Common/default.nix { inherit inputs pkgs config; })
    (import ../Common/nvidia.nix { inherit inputs pkgs config; })
    (import ../Common/desktop.nix { inherit inputs pkgs config; })
  ];
  hardware.graphics.extraPackages = [
    pkgs.intel-compute-runtime
    pkgs.intel-media-driver
  ];

  # nix.settings.max-jobs = 1;
  # services.ollama = {
  #     enable = true;
  #     acceleration = "cuda";
  # };

  zramSwap.enable = true;
  services.logind.extraConfig = ''HandlePowerKey=ignore'';
  networking.wg-quick.interfaces = {
    wg0 = {
      address = [ "10.0.0.5/24" "2a02:a03f:83ad:2101::5/128" ];
      privateKeyFile = "/home/user/.secrets/Wireguard/Aloria.key";
      listenPort = 51820;
      # postUp = "resolvectl dns wg0 10.0.0.1; resolvectl domain wg0 ~thomasave.be;";
      peers = [{
        publicKey = "/9ppjm3yeD0duDvxrqgcHscHmftXko+0s2RbivNEy2c=";
        allowedIPs = [ "10.0.0.1/8" "192.168.1.2/32" ];
        endpoint = "h.thomasave.be:13231";
        persistentKeepalive = 25;
      }];
    };
  };
  fileSystems."/home/server".device = pkgs.lib.mkForce "10.0.0.1:/home/server";

  networking.wireless.iwd.enable = true;
  networking.wireless.iwd.settings = {
    IPv6 = {
      Enabled = true;
    };
    Settings = {
      AutoConnect = true;
    };
  };
}
